#!/bin/bash
# Might want to drop this in ~/bin/ and chmod u+x it
#  Initial Author:Lin Yi <nilusyi@tencent.com>
#  Initial Date: 2022-02-08
#  Description: used to download the sources file from sources repositories
# set global variable
surl="https://git.opencloudos.tech/sources-stream"
#surl="https://git.opencloudos.tech/sources-stream"


# get the work dir
workdir=`pwd`
workdir_name=${workdir##*/}
# get spec file
num=`ls *.spec | wc -w`
# if spec files are more than one, we set the dir name as spec name,
# else, get it directly
if [ ${num} -gt 1 ]; then
    spec="${workdir_name}.spec"
else
    spec=`ls *.spec`
fi
if [ ! -f "${workdir}/${spec}" ]; then
    echo "[ERROR] spec file does not exist"
    exit 1;
fi
# get the repo name from spec
#repo_name=`rpm -q --qf "?%{NAME}?" --define "_sourcedir ${workdir}" --specfile ${spec} 2>&1 \
# | grep -v 'warning' | sed '/^$/d' | cut -d '?' -f 2`
#repo_name=`grep '^Name' ${spec} | head -1 | cut -d ':' -f 2 | sed 's/[[:space:]]//g'`
# TODO, ad-hoc the reponame=git_repo_name,should be fixed
repo_name=${workdir_name}
# download all the sources from sources file
source_file="${workdir}/sources"
if [ ! -f ${source_file} ]; then
    echo "[ERROR] sources file does not exist"
    exit 0;
fi
while IFS= read -r line;
do
    if [ -z "$line" ]; then
        continue
    fi
    file_name=`echo ${line} | sed 's/.*[(]//;s/[)].*//;'`
    file_hash=`echo ${line} | cut -d ' ' -f 4`
    # url format: /repo_name/file_name/sha512/file_hash/file_name
    file_url="${surl}/${repo_name}/${file_name}/sha512/${file_hash}/${file_name}"
    echo "downloading ${file_name}: ${file_url}"
    for i in `seq 10`
    do
        echo "try curl $i times."
        curl -L -f "${file_url}" -m 3600 -o "${file_name}" && break
    done
    if [ $? -eq 0 ]; then
        echo "success curl in ${i}st times."
    fi
    down_hash=`sha512sum ${workdir}/${file_name} | awk '{print $1}'`
    if [ "${file_hash}" != "${down_hash}" ]; then
        rm -f "${file_name}"
        echo "[ERROR] ${file_name} hash does not match hash from the sources file" >&2
        exit 1;
    fi
done < "${source_file}"
echo "get sources finished"
